@@ -23,6 +23,10 @@ public:
 //	void	set_file(char* fn);
 //	int	open();
 //	int	close();
+	imgwriter(const imgwriter &in) = delete;
+	imgwriter(imgwriter &&in) = delete;
+	imgwriter& operator=(const imgwriter &in) = delete;
+
 private:
 	char*		fname;
 	FILE*		iso;
