@@ -17,7 +17,7 @@
 //#endif
 #include <inttypes.h>
 
-#include <common_functions.h>
+#include "common_functions.h"
 #include "qpx_opcodes.h"
 
 typedef char	str_vendor[9];
@@ -231,8 +231,8 @@ static const	manuf	mi[]={
 	{ { 97, 48, 50 }, "Mitsui" },
 	{ { 97, 17,  0 }, "Moser Baer India" },
 	{ { 97, 25,  0 }, "MPO" },
-	{ { 97, 28, 20 }, "MultiMediaMasters & Machinary" },
-	{ { 97, 46, 20 }, "MultiMediaMasters & Machinary" },
+	{ { 97, 28, 20 }, "MultiMediaMasters & Machinery" },
+	{ { 97, 46, 20 }, "MultiMediaMasters & Machinery" },
 
 	{ { 97, 23, 20 }, "Nacar Media srl" },
 	{ { 97, 15, 30 }, "NAN-YA" },
@@ -581,8 +581,8 @@ static const	dev_desc _devtbl[]= {
 #define WTYPE_LJ		4
 
 typedef struct {
-	char wtype;
-	char dtype;
+	signed char wtype;
+	signed char dtype;
 	uint32_t	id;
 	char		name[32];
 } wr_mode;
